Zonis
---

A coro based callback system for many to one IPC setups.

`pip install zonis`


=======
See the [examples](https://github.com/Skelmis/Zonis/tree/master/examples) for simple use cases.
___

## Build the docs locally

If you want to build and run the docs locally using sphinx run
```
sphinx-autobuild -a docs docs/_build/html --watch zonis
```

this will build the docs and start a local server; additionally it will listed for changes to the source directory ``zonis`` and to the docs source directory ``docs/``.
You can find the builded files at ``docs/_build``.
